@@ -38,11 +38,12 @@
 #undef HAVE_NETBSD_IEEE_INTERFACE
 #undef HAVE_OPENBSD_IEEE_INTERFACE
 #undef HAVE_DARWIN_IEEE_INTERFACE
+#undef HAVE_DARWIN86_IEEE_INTERFACE
 
-/* Define this is IEEE comparisons work correctly (e.g. NaN != NaN) */
+/* Define this if IEEE comparisons work correctly (e.g. NaN != NaN) */
 #undef HAVE_IEEE_COMPARISONS
 
-/* Define this is IEEE denormalized numbers are available */
+/* Define this if IEEE denormalized numbers are available */
 #undef HAVE_IEEE_DENORMALS
 
 /* Define a rounding function which moves extended precision values
@@ -126,3 +127,6 @@
 #if defined(GSL_RANGE_CHECK_OFF) || !defined(GSL_RANGE_CHECK)
 #define GSL_RANGE_CHECK 0  /* turn off range checking by default internally */
 #endif
+
+/* Disable deprecated functions and enums while building */
+#define GSL_DISABLE_DEPRECATED 1
