@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GSL_MULTIFIT_H__
@@ -65,6 +65,16 @@ gsl_multifit_linear (const gsl_matrix * X,
                      double * chisq,
                      gsl_multifit_linear_workspace * work);
 
+int
+gsl_multifit_linear_svd (const gsl_matrix * X,
+                         const gsl_vector * y,
+                         double tol,
+                         size_t * rank,
+                         gsl_vector * c,
+                         gsl_matrix * cov,
+                         double *chisq, 
+                         gsl_multifit_linear_workspace * work);
+
 int
 gsl_multifit_wlinear (const gsl_matrix * X,
                       const gsl_vector * w,
@@ -74,6 +84,23 @@ gsl_multifit_wlinear (const gsl_matrix * X,
                       double * chisq,
                       gsl_multifit_linear_workspace * work);
 
+int
+gsl_multifit_wlinear_svd (const gsl_matrix * X,
+                          const gsl_vector * w,
+                          const gsl_vector * y,
+                          double tol,
+                          size_t * rank,
+                          gsl_vector * c,
+                          gsl_matrix * cov,
+                          double *chisq, 
+                          gsl_multifit_linear_workspace * work);
+
+int
+gsl_multifit_linear_est (const gsl_vector * x,
+                         const gsl_vector * c,
+                         const gsl_matrix * cov, double *y, double *y_err);
+
+
 __END_DECLS
 
 #endif /* __GSL_MULTIFIT_H__ */
