@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Author:  G. Jungman */
@@ -147,7 +147,7 @@ gamma_inc_Q_asymp_unif(const double a, const double x, gsl_sf_result * result)
 
   gsl_sf_result ln_term;
   const int stat_ln = gsl_sf_log_1plusx_mx_e(eps, &ln_term);  /* log(1+eps) - eps */
-  const double eta  = eps * sqrt(-2.0*ln_term.val/(eps*eps));
+  const double eta  = GSL_SIGN(eps) * sqrt(-2.0*ln_term.val);
 
   gsl_sf_result erfc;
 
@@ -506,7 +506,7 @@ gsl_sf_gamma_inc_Q_e(const double a, const double x, gsl_sf_result * result)
     }
   }
   else {
-    if(0.8*a < x) {
+    if(x > a - sqrt(a)) {
       /* Continued fraction again. The convergence
        * is a little slower here, but that is fine.
        * We have to trade that off against the slow
