@@ -56,6 +56,12 @@ FUNCTION (test, func) (size_t stride, size_t N)
       {
         int status = (FUNCTION(gsl_vector,isnull)(v) != 1);
         TEST (status, "_isnull" DESC " on calloc vector");
+        
+        status = (FUNCTION(gsl_vector,ispos)(v) != 0);
+        TEST (status, "_ispos" DESC " on calloc vector");
+
+        status = (FUNCTION(gsl_vector,isneg)(v) != 0);
+        TEST (status, "_isneg" DESC " on calloc vector");
       }
 
       FUNCTION (gsl_vector, free) (v);      /* free whatever is in v */
@@ -157,6 +163,12 @@ FUNCTION (test, func) (size_t stride, size_t N)
     
     status = (FUNCTION(gsl_vector,isnull)(v) != 1);
     TEST (status, "_isnull" DESC " on null vector") ;
+
+    status = (FUNCTION(gsl_vector,ispos)(v) != 0);
+    TEST (status, "_ispos" DESC " on null vector") ;
+
+    status = (FUNCTION(gsl_vector,isneg)(v) != 0);
+    TEST (status, "_isneg" DESC " on null vector") ;
   }
 
   {
@@ -164,13 +176,97 @@ FUNCTION (test, func) (size_t stride, size_t N)
 
     for (i = 0; i < N; i++)
       {
-        FUNCTION (gsl_vector, set) (v, i, (ATOMIC) i);
+        FUNCTION (gsl_vector, set) (v, i, (ATOMIC) (i % 10));
       }
     
     status = (FUNCTION(gsl_vector,isnull)(v) != 0);
-    TEST (status, "_isnull" DESC " on non-null vector") ;
+    TEST (status, "_isnull" DESC " on non-negative vector") ;
+
+    status = (FUNCTION(gsl_vector,ispos)(v) != 0);
+    TEST (status, "_ispos" DESC " on non-negative vector") ;
+
+    status = (FUNCTION(gsl_vector,isneg)(v) != 0);
+    TEST (status, "_isneg" DESC " on non-negative vector") ;
   }
 
+
+#ifndef UNSIGNED
+  {
+    int status = 0;
+
+    for (i = 0; i < N; i++)
+      {
+        FUNCTION (gsl_vector, set) (v, i, (ATOMIC) ((i % 10) - 5));
+      }
+    
+    status = (FUNCTION(gsl_vector,isnull)(v) != 0);
+    TEST (status, "_isnull" DESC " on mixed vector") ;
+
+    status = (FUNCTION(gsl_vector,ispos)(v) != 0);
+    TEST (status, "_ispos" DESC " on mixed vector") ;
+
+    status = (FUNCTION(gsl_vector,isneg)(v) != 0);
+    TEST (status, "_isneg" DESC " on mixed vector") ;
+  }
+
+  {
+    int status = 0;
+
+    for (i = 0; i < N; i++)
+      {
+        FUNCTION (gsl_vector, set) (v, i, -(ATOMIC) (i % 10));
+      }
+    
+    status = (FUNCTION(gsl_vector,isnull)(v) != 0);
+    TEST (status, "_isnull" DESC " on non-positive vector") ;
+
+    status = (FUNCTION(gsl_vector,ispos)(v) != 0);
+    TEST (status, "_ispos" DESC " on non-positive vector") ;
+
+    status = (FUNCTION(gsl_vector,isneg)(v) != 0);
+    TEST (status, "_isneg" DESC " on non-positive non-null vector") ;
+  }
+#endif
+
+  {
+    int status = 0;
+
+    for (i = 0; i < N; i++)
+      {
+        FUNCTION (gsl_vector, set) (v, i, (ATOMIC) (i % 10 + 1));
+      }
+    
+    status = (FUNCTION(gsl_vector,isnull)(v) != 0);
+    TEST (status, "_isnull" DESC " on positive vector") ;
+
+    status = (FUNCTION(gsl_vector,ispos)(v) != 1);
+    TEST (status, "_ispos" DESC " on positive vector") ;
+
+    status = (FUNCTION(gsl_vector,isneg)(v) != 0);
+    TEST (status, "_isneg" DESC " on positive vector") ;
+  }
+
+
+#if (!defined(UNSIGNED) && !defined(BASE_CHAR))
+  {
+    int status = 0;
+
+    for (i = 0; i < N; i++)
+      {
+        FUNCTION (gsl_vector, set) (v, i, -(ATOMIC) (i % 10 + 1));
+      }
+    
+    status = (FUNCTION(gsl_vector,isnull)(v) != 0);
+    TEST (status, "_isnull" DESC " on negative vector") ;
+
+    status = (FUNCTION(gsl_vector,ispos)(v) != 0);
+    TEST (status, "_ispos" DESC " on negative vector") ;
+
+    status = (FUNCTION(gsl_vector,isneg)(v) != 1);
+    TEST (status, "_isneg" DESC " on negative vector") ;
+  }
+#endif
+
   {
     int status = 0;
     
@@ -292,6 +388,65 @@ FUNCTION (test, func) (size_t stride, size_t N)
     TEST (status, "_reverse" DESC " reverses elements") ;
   }
 
+
+  {
+    int status = 0;
+    
+    QUALIFIED_VIEW(gsl_vector,view) v1 = FUNCTION(gsl_vector, view_array) (v->data, N*stride);
+    
+    for (i = 0; i < N; i++)
+      {
+        if (FUNCTION (gsl_vector, get) (&v1.vector, i*stride) != FUNCTION (gsl_vector, get) (v, i)) 
+          status = 1;
+      };
+
+    TEST (status, "_view_array" DESC);
+  }
+
+  {
+    int status = 0;
+    
+    QUALIFIED_VIEW(gsl_vector,view) v1 = FUNCTION(gsl_vector, view_array_with_stride) (v->data, stride, N*stride);
+    
+    for (i = 0; i < N; i++)
+      {
+        if (FUNCTION (gsl_vector, get) (&v1.vector, i) != FUNCTION (gsl_vector, get) (v, i)) 
+          status = 1;
+      };
+
+    TEST (status, "_view_array_with_stride" DESC);
+  }
+
+
+  {
+    int status = 0;
+    
+    QUALIFIED_VIEW(gsl_vector,view) v1 = FUNCTION(gsl_vector, subvector) (v, N/3, N/2);
+    
+    for (i = 0; i < N/2; i++)
+      {
+        if (FUNCTION (gsl_vector, get) (&v1.vector, i) != FUNCTION (gsl_vector, get) (v, (N/3) + i)) 
+          status = 1;
+      };
+
+    TEST (status, "_view_subvector" DESC);
+  }
+
+  {
+    int status = 0;
+    
+    QUALIFIED_VIEW(gsl_vector,view) v1 = FUNCTION(gsl_vector, subvector_with_stride) (v, N/5, 3, N/4);
+    
+    for (i = 0; i < N/4; i++)
+      {
+        if (FUNCTION (gsl_vector, get) (&v1.vector, i) != FUNCTION (gsl_vector, get) (v, (N/5) + 3*i)) 
+          status = 1;
+      };
+
+    TEST (status, "_view_subvector_with_stride" DESC);
+  }
+
+
   {
     BASE exp_max = FUNCTION(gsl_vector,get)(v, 0);
     BASE exp_min = FUNCTION(gsl_vector,get)(v, 0);
@@ -352,66 +507,54 @@ FUNCTION (test, func) (size_t stride, size_t N)
       TEST (imax != exp_imax, "_minmax_index returns correct maximum i");
       TEST (imin != exp_imin, "_minmax_index returns correct minimum i");
     }
+    
+#if FP
+    i = N/2;
+    FUNCTION(gsl_vector, set) (v, i, GSL_NAN);
+    exp_max = GSL_NAN; exp_min = GSL_NAN;
+    exp_imax = i; exp_imin = i;
+
+    {
+      BASE max = FUNCTION(gsl_vector, max) (v) ;
+      gsl_test_abs (max, exp_max, 0, "_max returns correct maximum value for NaN");
+    }
+
+    {
+      BASE min = FUNCTION(gsl_vector, min) (v) ;
+      gsl_test_abs (min, exp_min, 0, "_min returns correct minimum value for NaN");
+    }
+
+    {
+      BASE min, max;
+      FUNCTION(gsl_vector, minmax) (v, &min, &max);
+
+      gsl_test_abs (max, exp_max, 0, "_minmax returns correct maximum value for NaN");
+      gsl_test_abs (min, exp_min, 0, "_minmax returns correct minimum value for NaN");
+    }
+
+
+    {
+      size_t imax =  FUNCTION(gsl_vector, max_index) (v) ;
+      TEST (imax != exp_imax, "_max_index returns correct maximum i for NaN");
+    }
+
+    {
+      size_t imin = FUNCTION(gsl_vector, min_index) (v) ;
+      TEST (imin != exp_imin, "_min_index returns correct minimum i for NaN");
+    }
+
+    {
+      size_t imin, imax;
+
+      FUNCTION(gsl_vector, minmax_index) (v,  &imin, &imax);
+
+      TEST (imax != exp_imax, "_minmax_index returns correct maximum i for NaN");
+      TEST (imin != exp_imin, "_minmax_index returns correct minimum i for NaN");
+    }
+#endif
+
   }
 
-  {
-    int status = 0;
-    
-    QUALIFIED_VIEW(gsl_vector,view) v1 = FUNCTION(gsl_vector, view_array) (v->data, N*stride);
-    
-    for (i = 0; i < N; i++)
-      {
-        if (FUNCTION (gsl_vector, get) (&v1.vector, i*stride) != FUNCTION (gsl_vector, get) (v, i)) 
-          status = 1;
-      };
-
-    TEST (status, "_view_array" DESC);
-  }
-
-  {
-    int status = 0;
-    
-    QUALIFIED_VIEW(gsl_vector,view) v1 = FUNCTION(gsl_vector, view_array_with_stride) (v->data, stride, N*stride);
-    
-    for (i = 0; i < N; i++)
-      {
-        if (FUNCTION (gsl_vector, get) (&v1.vector, i) != FUNCTION (gsl_vector, get) (v, i)) 
-          status = 1;
-      };
-
-    TEST (status, "_view_array_with_stride" DESC);
-  }
-
-
-  {
-    int status = 0;
-    
-    QUALIFIED_VIEW(gsl_vector,view) v1 = FUNCTION(gsl_vector, subvector) (v, N/3, N/2);
-    
-    for (i = 0; i < N/2; i++)
-      {
-        if (FUNCTION (gsl_vector, get) (&v1.vector, i) != FUNCTION (gsl_vector, get) (v, (N/3) + i)) 
-          status = 1;
-      };
-
-    TEST (status, "_view_subvector" DESC);
-  }
-
-  {
-    int status = 0;
-    
-    QUALIFIED_VIEW(gsl_vector,view) v1 = FUNCTION(gsl_vector, subvector_with_stride) (v, N/5, 3, N/4);
-    
-    for (i = 0; i < N/4; i++)
-      {
-        if (FUNCTION (gsl_vector, get) (&v1.vector, i) != FUNCTION (gsl_vector, get) (v, (N/5) + 3*i)) 
-          status = 1;
-      };
-
-    TEST (status, "_view_subvector_with_stride" DESC);
-  }
-
-
 
   FUNCTION (gsl_vector, free) (v0);      /* free whatever is in v */
 }
